package org.robolectric.shadows;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.app.Activity;
import android.app.Application;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.robolectric.Robolectric;
import org.robolectric.TestRunners;

import static org.fest.assertions.api.Assertions.assertThat;
import static org.junit.Assert.assertSame;

@RunWith(TestRunners.WithDefaults.class)
public class AccountManagerTest {

    Application app;

    @Before
    public void setUp() throws Exception {
        app = Robolectric.application;
    }

    @Test
    public void testGet() {
        AccountManager appAM = AccountManager.get(app);
        assertThat(appAM).isNotNull();
        assertSame(AccountManager.get(app), appAM);

        Activity a = new Activity();
        assertThat(AccountManager.get(a)).isNotNull();
        assertThat(AccountManager.get(a)).isNotSameAs(appAM);
    }

    @Test
    public void testGetAccounts() {
        AccountManager am = AccountManager.get(app);
        assertThat(am.getAccounts()).isNotNull();
        assertThat(am.getAccounts().length).isEqualTo(0);

        Account a1 = new Account("name_a", "type_a");
        Robolectric.shadowOf(am).addAccount(a1);
        assertThat(am.getAccounts()).isNotNull();
        assertThat(am.getAccounts().length).isEqualTo(1);
        assertThat(am.getAccounts()[0]).isSameAs(a1);

        Account a2 = new Account("name_b", "type_b");
        Robolectric.shadowOf(am).addAccount(a2);
        assertThat(am.getAccounts()).isNotNull();
        assertThat(am.getAccounts().length).isEqualTo(2);
        assertThat(am.getAccounts()[1]).isSameAs(a2);
    }

    @Test
    public void testGetAccountsByType() {
        AccountManager am = AccountManager.get(app);
        assertThat(am.getAccountsByType("name_a")).isNotNull();
        assertThat(am.getAccounts().length).isEqualTo(0);

        Account a1 = new Account("name_a", "type_a");
        Robolectric.shadowOf(am).addAccount(a1);
        Account[] accounts = am.getAccountsByType("type_a");
        assertThat(accounts).isNotNull();
        assertThat(accounts.length).isEqualTo(1);
        assertThat(accounts[0]).isSameAs(a1);

        Account a2 = new Account("name_b", "type_b");
        Robolectric.shadowOf(am).addAccount(a2);
        accounts = am.getAccountsByType("type_a");
        assertThat(accounts).isNotNull();
        assertThat(accounts.length).isEqualTo(1);
        assertThat(accounts[0]).isSameAs(a1);

        Account a3 = new Account("name_c", "type_a");
        Robolectric.shadowOf(am).addAccount(a3);
        accounts = am.getAccountsByType("type_a");
        assertThat(accounts).isNotNull();
        assertThat(accounts.length).isEqualTo(2);
        assertThat(accounts[0]).isSameAs(a1);
        assertThat(accounts[1]).isSameAs(a3);
    }

}
